package Bundle::Knetrix;

$VERSION = "1.0";

1;

__END__

=head1 NAME

Bundle::Knetrix - A bundle to install all Knetrix required modules

=head1 SYNOPSIS

 perl -MCPAN -e 'install Bundle::Knetrix'

=head1 CONTENTS

Apache
AutoLoader
Business::CreditCard
Carp
Class::Delegation
Class::MakeMethods::Composite::Hash
Compress::Zlib
Crypt::TripleDES
Cyrus::SIEVE::managesieve
Data::Dumper
DBI
Digest::MD5
DynaLoader
Email::Valid
Error
Exporter
ExtUtils::MakeMaker
File::Spec
Geo::PostalCode
HTML::Entities
HTML::Parser
Image::Size
Image::Thumbnail
IO::Scalar
IPC::Shareable
IPC::SysV
Log::Log4perl
Mail::IMAPClient
Mail::IMAPClient::BodyStructure
MIME::Base64
MIME::Decoder
Number::Format
PDF::Template
POSIX
Storable
Switch
Symbol
Template
Term::ANSIColor
Tie::Hash::Expire
Time::HiRes
Time::Local
URI::Escape
URI::Find::Schemeless
XML::Simple
XML::XPath

head1 DESCRIPTION

This bundle defines modules, required by Knetrix.

=head1 AUTHOR



=cut 

